@@ -28,7 +28,7 @@ from datamodel_code_generator import (
     generate,
 )
 
-from .format import PythonVersion
+from .format import PythonVersion, is_supported_in_black
 
 
 class Exit(IntEnum):
@@ -45,7 +45,6 @@ def sig_int_handler(_: int, __: Any) -> None:  # pragma: no cover
 
 signal.signal(signal.SIGINT, sig_int_handler)
 
-
 arg_parser = ArgumentParser()
 arg_parser.add_argument(
     '--input', help='Input file/directory (default: stdin)',
@@ -78,7 +77,6 @@ arg_parser.add_argument(
     default=None,
 )
 
-
 arg_parser.add_argument(
     '--allow-population-by-field-name',
     help='Allow population by field name',
@@ -114,6 +112,20 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--use-schema-description',
+    help='Use schema description to populate class docstring',
+    action='store_true',
+    default=None,
+)
+
+arg_parser.add_argument(
+    '--reuse-model',
+    help='Re-use models on the field when a module has the model with the same content',
+    action='store_true',
+    default=None,
+)
+
 arg_parser.add_argument(
     '--class-name', help='Set class name of root model', default=None,
 )
@@ -128,7 +140,7 @@ arg_parser.add_argument('--aliases', help='Alias mapping file', type=FileType('r
 arg_parser.add_argument(
     '--target-python-version',
     help='target python version (default: 3.7)',
-    choices=['3.6', '3.7'],
+    choices=[v.value for v in PythonVersion],
 )
 arg_parser.add_argument(
     '--validation',
@@ -178,6 +190,8 @@ class Config(BaseModel):
     force_optional: bool = False
     class_name: Optional[str] = None
     use_standard_collections: bool = False
+    use_schema_description: bool = False
+    reuse_model: bool = False
 
     def merge_args(self, args: Namespace) -> None:
         for field_name in self.__fields__:
@@ -220,6 +234,15 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
     config = Config.parse_obj(pyproject_toml)
     config.merge_args(namespace)
 
+    if not is_supported_in_black(config.target_python_version):  # pragma: no cover
+        print(
+            f"Installed black doesn't support Python version {config.target_python_version.value}.\n"
+            f"You have to install a newer black.\n"
+            f"Installed black version: {black.__version__}",
+            file=sys.stderr,
+        )
+        return Exit.ERROR
+
     if config.debug:  # pragma: no cover
         enable_debug_message()
 
@@ -274,6 +297,8 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             force_optional_for_required_fields=config.force_optional,
             class_name=config.class_name,
             use_standard_collections=config.use_standard_collections,
+            use_schema_description=config.use_schema_description,
+            reuse_model=config.reuse_model,
         )
         return Exit.OK
     except InvalidClassNameError as e:
