@@ -1,6 +1,6 @@
 from enum import Enum
 from pathlib import Path
-from typing import Dict
+from typing import Dict, Optional
 
 import black
 import isort
@@ -11,23 +11,31 @@ class PythonVersion(Enum):
     PY_36 = '3.6'
     PY_37 = '3.7'
     PY_38 = '3.8'
+    PY_39 = '3.9'
 
 
 BLACK_PYTHON_VERSION: Dict[PythonVersion, black.TargetVersion] = {
-    PythonVersion.PY_36: black.TargetVersion.PY36,
-    PythonVersion.PY_37: black.TargetVersion.PY37,
-    PythonVersion.PY_38: black.TargetVersion.PY38,
+    v: getattr(black.TargetVersion, f'PY{v.name.split("_")[-1]}')
+    for v in PythonVersion
+    if hasattr(black.TargetVersion, f'PY{v.name.split("_")[-1]}')
 }
 
 
-def format_code(code: str, python_version: PythonVersion, settings_path: Path) -> str:
+def is_supported_in_black(python_version: PythonVersion) -> bool:  # pragma: no cover
+    return python_version in BLACK_PYTHON_VERSION
+
+
+def format_code(
+    code: str, python_version: PythonVersion, settings_path: Optional[Path] = None
+) -> str:
+    if not settings_path:
+        settings_path = Path().resolve()
     code = apply_isort(code, settings_path)
     code = apply_black(code, python_version, settings_path)
     return code
 
 
 def apply_black(code: str, python_version: PythonVersion, settings_path: Path) -> str:
-
     root = black.find_project_root((settings_path,))
     path = root / "pyproject.toml"
     if path.is_file():
