@@ -1249,3 +1249,27 @@ def test_main_invalid_enum_name():
         )
     with pytest.raises(SystemExit):
         main()
+
+
+@freeze_time('2019-07-26')
+def test_main_json_reuse_model():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(JSON_DATA_PATH / 'duplicate_models.json'),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'json',
+                '--reuse-model',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (EXPECTED_MAIN_PATH / 'main_json_resuse_model' / 'output.py').read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
